package it.unibo.tw0708.utils;

/**
 * A class to generate a declaration statement
 * basing on people name, gender and address
 * @author pisi79
 */
public class Declaration {

	/**
	 * The nameof the person stating something
	 */
	private String name;

	/**
	 * The surname of the person stating something
	 */
	private String surname;

	/**
	 * The gender of the person stating something
	 */
	private boolean male;
	

	/**
	 * Constructor
	 * @param name the name of the person stating something  
	 * @param surname the surname of the person stating something
	 */
	public Declaration(String name, String surname, boolean male) 
	throws Exception {
		if ( name == null || name.equals("") || surname == null || surname.equals("") )
			throw new Exception("Name and surname must be provided!");
		this.name = name;
		this.surname = surname;
		this.male = male;
	}

	/**
	 * The street where the person stating something lives
	 */
	private String address;

	/**
	 * The city where the person stating something lives
	 */
	private String city;

	/**
	 * The country where the person stating something lives
	 */
	private String country;
	
	/**
	 * A setter method for the optional information about the residence of the person stating something 
	 * @param address the street where he/she lives
	 * @param city the city where he/she lives
	 * @param country the country where he/she lives
	 */
	public void set(String address, String city, String country) {
		this.address = address;
		this.city = city;
		this.country = country;
	}

	/**
	 * The sole biz logic method.
	 * Method uses the member fields of the object that instantiates this class
	 * and returns a statement sentence
	 * @param statement the assertion
	 * @return the complete sentence
	 */
	public String declaresThat(String statement) {
		String result = "";
		result += name + " " + surname;
		if ( address != null && city != null && country != null )
			if ( !address.equals("") && !city.equals("") && !country.equals("") )
				result += ", living in " + address + ", " + city + ", " + country + ",";
		result += " declares that ";
		if ( this.male )
			result += "he ";
		else
			result += "she ";
		result += statement;
		return result;
	}

}